TestFramesNested
open | ../tests/html/NestedFrames.html |
verifyTitle | NestedFrames |
verifyTextNotPresent | This is a test |
selectFrame | mainFrame |
verifyTitle | NestedFrames2 |
selectFrame | mainFrame |
verifyTitle | AUT |
selectFrame | mainFrame |
verifyLocation | */tests/html/test_open.html |
verifyTextPresent | This is a test |
selectFrame | relative=up |
verifyTitle | AUT |
verifyTextNotPresent | This is a test |

Select a frame using a DOM expression pointing to the frame itself

selectFrame | relative=top |
verifyTitle | NestedFrames |
selectFrame | dom=window.frames[1] |
verifyTitle | NestedFrames2 |

Select a frame by index

selectFrame | relative=top |
verifyTitle | NestedFrames |
selectFrame | index=1 |
verifyTitle | NestedFrames2 |

Select a frame using a locator expression pointing to the frame element (in this case, "foo" is the ID of the mainFrame element)

selectFrame | relative=top |
verifyTitle | NestedFrames |
selectFrame | foo |
verifyTitle | NestedFrames2 |

Select a frame using a DOM expression pointing to a nested frame

selectFrame | relative=top |
verifyTitle | NestedFrames |
selectFrame | dom=window.frames["mainFrame"].frames["mainFrame"] |
verifyTitle | AUT |